"use client";
import FormBuilder from "@/components/FormBuilder/form-builder";
import InputField from "@/components/FormBuilder/FormFields/input-field";
import useFormBuilder from "@/components/FormBuilder/hooks/use-form-builder";
import prepareFields from "@/components/FormBuilder/utils/prepare-fields";
import Yup from "@/components/FormBuilder/utils/yup";
import PhoneInput from "@/components/ui/phone-input";
import { useUserInfo } from "@/servers/data/use-userinfo";
import { useTranslations } from "next-intl";
import { useEffect, useMemo } from "react";



export default function Page() {
	const t = useTranslations();
	const { userInfo } = useUserInfo();

	const fields = useMemo(
		() =>
			prepareFields({
				first_name: {
					yup: Yup.string().required(t("This field is required")),
					type: "input",
					component: InputField,
					componentProps: ({ }) => ({
						type: "text",
						labelClassName: "text-white",
						placeholder: t("FirstName"),
						containerClassName: "col-span-4",
					}),
				},
				middle_name: {
					yup: Yup.string().required(t("This field is required")),
					type: "input",
					component: InputField,
					componentProps: ({ }) => ({
						type: "text",
						labelClassName: "text-white",
						placeholder: t("MiddleName"),
						containerClassName: "col-span-4",
					}),
				},
				pool_numbers: {
					yup: Yup.string().required(t("This field is required")),
					type: "input",
					component: InputField,
					componentProps: ({ }) => ({
						type: "text",
						labelClassName: "text-white",
						placeholder: t("pool_numbers"),
						containerClassName: "col-span-4",
					}),
				},
				last_name: {
					yup: Yup.string().required(t("This field is required")),
					type: "input",
					component: InputField,
					componentProps: ({ }) => ({
						type: "text",
						labelClassName: "text-white",
						placeholder: t("LastName"),
						containerClassName: "col-span-4",
					}),
				},
				region: {
					yup: Yup.string().required(t("This field is required")),
					type: "input",
					component: InputField,
					componentProps: ({ }) => ({
						type: "text",
						labelClassName: "text-white",
						placeholder: t("region"),
						containerClassName: "col-span-4",
					}),
				},
				isRoomExist: {
					yup: Yup.string().required(t("This field is required")),
					type: "input",
					component: InputField,
					componentProps: ({ }) => ({
						type: "text",
						labelClassName: "text-white",
						placeholder: t("isRoomExist"),
						containerClassName: "col-span-4",
					}),
				},
				phone: {
					yup: Yup.string().optional(),
					type: "input",
					component: (props) => (
						<div className="col-span-4 rounded-md border border-gray-300 bg-white h-11 mt-3 p-2">
							<PhoneInput
								{...props}
								value={userInfo?.phone?.slice(3)}
								onChange={(value: string | number) => {
									if (props.onChange) {
										props.onChange(value.toString());
									}
								}}
								labelclassName="text-right"
								className="h-11 -mt-2"
								disabled={true}
							/>
						</div>
					),
					componentProps: ({ }) => ({
						type: "text",
						labelClassName: "text-white",
						placeholder: t("Phone"),
						containerClassName: "col-span-4",
					}),
				},
				building: {
					yup: Yup.string().required(t("This field is required")),
					type: "input",
					component: InputField,
					componentProps: ({ }) => ({
						type: "text",
						labelClassName: "text-white",
						placeholder: t("building"),
						containerClassName: "col-span-4",
					}),
				},
				time_visit: {
					yup: Yup.string().required(t("This field is required")),
					type: "input",
					component: InputField,
					componentProps: ({ }) => ({
						type: "text",
						labelClassName: "text-white",
						placeholder: t("time_visit"),
						containerClassName: "col-span-4",
					}),
				},
			}),
		[t]
	);

	const FormHooks = useFormBuilder(fields, {
		defaultValues: {
			first_name: "",
			middle_name: "",
			last_name: "",
			building: "",
			isRoomExist: "",
			phone: "",
			region: "",
			pool_numbers: "",
			time_visit: "",
		},
	});

	useEffect(() => {
		if (userInfo) {
			const { first_name, middle_name, last_name, building, isRoomExist, phone, region, pool_numbers, time_visit } = userInfo;
			FormHooks.reset({ first_name, middle_name, last_name, building, isRoomExist, phone: phone?.slice(3), region, pool_numbers, time_visit });
		}
	}, [FormHooks, userInfo]);


	console.log("FormHooks: ", FormHooks.watch());
	return (
		<div className="h-screen w-full bg-4">
			<div
				className="flex flex-col items-center justify-start gap-16 h-full"
			>
				<div className="border-[1px] rounded-md p-2 w-[700px] backdrop-blur-md mt-20">
					<p className="text-4xl text-white text-center font-medium">
						{t("Request a vistit")}
					</p>
				</div>
				<div className="border-[1px] rounded-md p-2 w-[900px] backdrop-blur-md">
					<div className="flex flex-col items-center justify-center gap-8 p-8">
						<FormBuilder fields={fields} FormHooks={FormHooks} />
					</div>

					<div className="flex flex-col items-center justify-center gap-4 p-4">
						<span className="text-white">يرجى إدخال المعلومات بالشكل الصحيح، وسنتواصل معك للتأكيد</span>
						<button
							className="w-32 text-lg text-white py-2 bg-gradient-to-r from-[#1E1E1E] to-[rgba(30,30,30,0.7)] rounded-full transition-transform duration-300 ease-in-out hover:scale-105 hover:shadow-xl focus:outline-none focus:ring-4 focus:ring-gray-600"
							onClick={undefined}
							style={{ boxShadow: "#0000008f 0 5px 5px" }}
						>
							{t("Accept")}
						</button>
					</div>
				</div>
			</div>
		</div>
	);
}
